==> rapid_widgets_library-0.2.3.tar.gz: lib/custom-dropdownButton.dart <==
/*
Description:

Dynamically creates a dropdown material widget which enables the user to select from a list of Strings or Images.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-dropdownButton.dart';

Usage:

The parameters such as hintText,listType,itemsList,width,fillColor,height,imageHeight,imageWidth,etc can be passed using the 'DropDownParameters' class.
For a list of Strings listType='String' & itemsList: ['Option A','Option B','Option C']
For a list of Asset Images listType='AssetImage' & itemsList: ['AssetImagePath1','AssetImagePath2','AssetImagePath3']
For a list of Network Images listType='NetworkImage' & itemsList: ['NetworkImagePath1','NetworkImagePath2','NetworkImagePath3']

'void Function(int ,String) callback' function is passed which returns the index & value of the item selected from the dropdown.

- Defining the callback and dropdown button objects

  DropDownParameters dropdownObject = DropDownParameters(itemsList: ['Pune','Mumbai','Delhi','Bangalore'],hintText: 'Select City',listType: 'String',fillColor: Colors.orange,borderRadius: 10,width: 200,textColor: Colors.black,itemsBgColor: Colors.yellow,shadowColor: Colors.black,shadowBlurRadius: 5,shadowSpreadRadius: 2);

    onSelect(int i,String s){
      print(i);
      print(s);
    }

- Object call for the widget

CustomDropdownButton(dropdownObject,onSelect),


Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/theme.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:rapid_widgets_library/consts.dart' as con;

class CustomDropdownButton extends StatefulWidget {
  final DropDownParameters param;
  final void Function(int, String) callback;

  CustomDropdownButton(this.param, this.callback) : super();

  @override
  _CustomDropdownButton createState() => _CustomDropdownButton(param, callback);
}

class _CustomDropdownButton extends State<CustomDropdownButton> {
  final DropDownParameters param;
  void Function(int, String) callback;

  _CustomDropdownButton(this.param, this.callback);

  String dropdownValue;

  Widget build(BuildContext context) {
    if (param == null) {
      return Container(
        height: con.heightSixty,
        width: con.heightHundred + con.heightFifty,
        decoration: BoxDecoration(
            borderRadius:
                BorderRadius.all(Radius.circular(con.circular_radius)),
            color: Theme.of(context).buttonColor,
            boxShadow: [
              BoxShadow(
                  color: mediumGreyThemeData().scaffoldBackgroundColor,
                  offset: Offset(
                    con.shadow_offsetx,
                    con.shadow_offsety,
                  ),
                  blurRadius: con.blur_radius,
                  spreadRadius: con.spread_radius)
            ]),
        child: Theme(
          data: Theme.of(context).copyWith(
              canvasColor: Theme.of(context).canvasColor,
              // background color for the dropdown items
              buttonTheme: ButtonTheme.of(context).copyWith(
                alignedDropdown: true,
              )),
          child: DropdownButtonHideUnderline(
            child: DropdownButton<String>(
              items: <String>[
                con.optionA,
                con.optionB,
                con.optionC,
                con.optionD
              ].map<DropdownMenuItem<String>>((String value) {
                return DropdownMenuItem<String>(
                  value: value,
                  child: Text(value,
                      overflow: TextOverflow.ellipsis,
                      style: TextStyle(
                        fontSize: con.font_medium,
                        color: Theme.of(context).textTheme.bodyText1.color,
                      )),
                );
              }).toList(),
              hint: Text(
                con.sampleText,
                overflow: TextOverflow.ellipsis,
              ),
              // setting hint
              onChanged: (String value) {
                setState(() {
                  dropdownValue = value;
                  print(dropdownValue);
                });
              },

              value: dropdownValue,
            ),
          ),
        ),
      );
    } else {
      return Container(
        height: ((widget.param.height) != null)
            ? widget.param.height
            : con.heightSixty,
        width: ((widget.param.width) != null)
            ? widget.param.width
            : con.dropDown_width,
        decoration: BoxDecoration(
            borderRadius: BorderRadius.all(Radius.circular(
                (param.borderRadius != null)
                    ? param.borderRadius
                    : con.circular_radius)),
            color: (widget.param.fillColor != null)
                ? widget.param.fillColor
                : Theme.of(context).buttonColor,
            boxShadow: [
              BoxShadow(
                  color: (widget.param.shadowColor == null)
                      ? mediumGreyThemeData().scaffoldBackgroundColor
                      : widget.param.shadowColor,
                  offset: Offset(
                      (widget.param.shadowOffsetX == null)
                          ? con.shadow_offsetx
                          : widget.param.shadowOffsetX,
                      (widget.param.shadowOffsetY == null)
                          ? con.shadow_offsety
                          : widget.param.shadowOffsetY),
                  blurRadius: (widget.param.shadowBlurRadius == null)
                      ? con.blur_radius
                      : widget.param.shadowBlurRadius,
                  spreadRadius: (widget.param.shadowSpreadRadius == null)
                      ? con.spread_radius
                      : widget.param.shadowSpreadRadius)
            ]),
        child: Theme(
            data: Theme.of(context).copyWith(
                canvasColor: (param.itemsBgColor != null)
                    ? param.itemsBgColor
                    : Theme.of(context).canvasColor,
                // background color for the dropdown items
                buttonTheme: ButtonTheme.of(context).copyWith(
                  alignedDropdown: true,
                )),
            child: DropdownButtonHideUnderline(
              child: DropdownButton<String>(
                key: param.key,

                items: widget.param.itemsList.map((String value) {
                  return DropdownMenuItem<String>(
                    value: value,
                    child: (param.listType == con.String)
                        ? Text(
                            value,
                            overflow: TextOverflow.ellipsis,
                            style: TextStyle(
                                fontSize: (widget.param.fontSize != null)
                                    ? widget.param.fontSize
                                    : con.font_medium,
                                color: (param.textColor != null)
                                    ? param.textColor
                                    : Theme.of(context)
                                        .textTheme
                                        .bodyText1
                                        .color,
                                fontWeight: widget.param.fontWeight),
                          )
                        : (param.listType == con.NetworkImage)
                            ? Image.network(
                                value,
                                height: (widget.param.imageHeight == null)
                                    ? con.heightSixty
                                    : widget.param.imageHeight,
                                width: (widget.param.imageWidth == null)
                                    ? con.image_width
                                    : widget.param.imageWidth,
                              )
                            : (param.listType == con.AsseImage)
                                ? Image.asset(
                                    value,
                                    height: (widget.param.imageHeight == null)
                                        ? con.heightSixty
                                        : widget.param.imageHeight,
                                    width: (widget.param.imageWidth == null)
                                        ? con.image_width
                                        : widget.param.imageWidth,
                                  )
                                : Text(
                                    value,
                                    style: TextStyle(
                                      fontSize: (widget.param.fontSize != null)
                                          ? widget.param.fontSize
                                          : con.font_medium,
                                      color: (param.textColor != null)
                                          ? param.textColor
                                          : Theme.of(context)
                                              .textTheme
                                              .bodyText2
                                              .color,
                                      fontWeight: (param.fontWeight != null)
                                          ? param.fontWeight
                                          : Theme.of(context)
                                              .textTheme
                                              .bodyText2
                                              .fontWeight,
                                      fontFamily: (param.fontFamily != null)
                                          ? param.fontFamily
                                          : Theme.of(context)
                                              .textTheme
                                              .bodyText2
                                              .fontFamily,
                                      fontStyle: (param.fontStyle != null)
                                          ? param.fontStyle
                                          : Theme.of(context)
                                              .textTheme
                                              .bodyText2
                                              .fontStyle,
                                    ),
                                  ),
                  );
                }).toList(),
                hint: Text(
                  (widget.param.hintText != null)
                      ? widget.param.hintText
                      : con.sampleText,
                  overflow: TextOverflow.ellipsis,
                  textAlign: (widget.param.textAlign == null)
                      ? TextAlign.left
                      : widget.param.textAlign,
                  style: TextStyle(
                    fontSize: (widget.param.fontSize != null)
                        ? widget.param.fontSize
                        : con.font_medium,
                    color: (param.hintTextColor != null)
                        ? param.hintTextColor
                        : Theme.of(context).textTheme.subtitle1.color,
                    fontWeight: (param.hintFontWeight != null)
                        ? param.hintFontWeight
                        : Theme.of(context).textTheme.subtitle1.fontWeight,
                    fontFamily: (param.hintfontFamily != null)
                        ? param.hintfontFamily
                        : Theme.of(context).textTheme.subtitle1.fontFamily,
                    fontStyle: (param.hintFontStyle != null)
                        ? param.hintFontStyle
                        : Theme.of(context).textTheme.subtitle1.fontStyle,
                  ),
                ),
                // setting hint
                onChanged: (String value) {
                  setState(() {
                    dropdownValue = value;
                    widget.callback(
                        widget.param.itemsList.indexOf(value), dropdownValue);
                  });
                },

                value: dropdownValue,
              ),
            )),
      );
    }
  }
}

==> rapid_widgets_library-0.2.33.tar.gz: lib/custom-dropdownButton.dart <==
/*
Description:

Dynamically creates a dropdown material widget which enables the user to select from a list of Strings or Images.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-dropdownButton.dart';

Usage:

The parameters such as hintText,listType,itemsList,width,fillColor,height,imageHeight,imageWidth,etc can be passed using the 'DropDownParameters' class.
For a list of Strings listType='String' & itemsList: ['Option A','Option B','Option C']
For a list of Asset Images listType='AssetImage' & itemsList: ['AssetImagePath1','AssetImagePath2','AssetImagePath3']
For a list of Network Images listType='NetworkImage' & itemsList: ['NetworkImagePath1','NetworkImagePath2','NetworkImagePath3']

'void Function(int ,String) callback' function is passed which returns the index & value of the item selected from the dropdown.

- Defining the callback and dropdown button objects

  DropDownParameters dropdownObject = DropDownParameters(itemsList: ['Pune','Mumbai','Delhi','Bangalore'],hintText: 'Select City',listType: 'String',fillColor: Colors.orange,borderRadius: 10,width: 200,textColor: Colors.black,itemsBgColor: Colors.yellow,shadowColor: Colors.black,shadowBlurRadius: 5,shadowSpreadRadius: 2);

    onSelect(int i,String s){
      print(i);
      print(s);
    }

- Object call for the widget

CustomDropdownButton(dropdownObject,onSelect),


Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/theme.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:rapid_widgets_library/consts.dart' as con;

class CustomDropdownButton extends StatefulWidget {
  final DropDownParameters param;
  final void Function(int, String) callback;

  CustomDropdownButton(this.param, this.callback) : super();

  @override
  _CustomDropdownButton createState() => _CustomDropdownButton(param, callback);
}

class _CustomDropdownButton extends State<CustomDropdownButton> {
  final DropDownParameters param;
  void Function(int, String) callback;

  _CustomDropdownButton(this.param, this.callback);

  String dropdownValue;

  Widget build(BuildContext context) {
    if (param == null) {
      return Container(
        height: con.heightSixty,
        width: con.heightHundred + con.heightFifty,
        decoration: BoxDecoration(
            borderRadius:
                BorderRadius.all(Radius.circular(con.circular_radius)),
            color: Theme.of(context).buttonColor,
            boxShadow: [
              BoxShadow(
                  color: mediumGreyThemeData().scaffoldBackgroundColor,
                  offset: Offset(
                    con.shadow_offsetx,
                    con.shadow_offsety,
                  ),
                  blurRadius: con.blur_radius,
                  spreadRadius: con.spread_radius)
            ]),
        child: Theme(
          data: Theme.of(context).copyWith(
              canvasColor: Theme.of(context).canvasColor,
              // background color for the dropdown items
              buttonTheme: ButtonTheme.of(context).copyWith(
                alignedDropdown: true,
              )),
          child: DropdownButtonHideUnderline(
            child: DropdownButton<String>(
              items: <String>[
                con.optionA,
                con.optionB,
                con.optionC,
                con.optionD
              ].map<DropdownMenuItem<String>>((String value) {
                return DropdownMenuItem<String>(
                  value: value,
                  child: Text(value,
                      overflow: TextOverflow.ellipsis,
                      style: TextStyle(
                        fontSize: con.font_medium,
                        color: Theme.of(context).textTheme.bodyText1.color,
                      )),
                );
              }).toList(),
              hint: Text(
                con.sampleText,
                overflow: TextOverflow.ellipsis,
              ),
              // setting hint
              onChanged: (String value) {
                setState(() {
                  dropdownValue = value;
                  print(dropdownValue);
                });
              },

              value: dropdownValue,
            ),
          ),
        ),
      );
    } else {
      return Container(
        height: ((widget.param.height) != null)
            ? widget.param.height
            : con.heightSixty,
        width: ((widget.param.width) != null)
            ? widget.param.width
            : con.dropDown_width,
        decoration: BoxDecoration(
            borderRadius: BorderRadius.all(Radius.circular(
                (param.borderRadius != null)
                    ? param.borderRadius
                    : con.circular_radius)),
            color: (widget.param.fillColor != null)
                ? widget.param.fillColor
                : Theme.of(context).buttonColor,
            boxShadow: [
              BoxShadow(
                  color: (widget.param.shadowColor == null)
                      ? mediumGreyThemeData().scaffoldBackgroundColor
                      : widget.param.shadowColor,
                  offset: Offset(
                      (widget.param.shadowOffsetX == null)
                          ? con.shadow_offsetx
                          : widget.param.shadowOffsetX,
                      (widget.param.shadowOffsetY == null)
                          ? con.shadow_offsety
                          : widget.param.shadowOffsetY),
                  blurRadius: (widget.param.shadowBlurRadius == null)
                      ? con.blur_radius
                      : widget.param.shadowBlurRadius,
                  spreadRadius: (widget.param.shadowSpreadRadius == null)
                      ? con.spread_radius
                      : widget.param.shadowSpreadRadius)
            ]),
        child: Theme(
            data: Theme.of(context).copyWith(
                canvasColor: (param.itemsBgColor != null)
                    ? param.itemsBgColor
                    : Theme.of(context).canvasColor,
                // background color for the dropdown items
                buttonTheme: ButtonTheme.of(context).copyWith(
                  alignedDropdown: true,
                )),
            child: DropdownButtonHideUnderline(
              child: DropdownButton<String>(
                key: param.key,

                items: widget.param.itemsList.map((String value) {
                  return DropdownMenuItem<String>(
                    value: value,
                    child: (param.listType == con.String)
                        ? Text(
                            value,
                            overflow: TextOverflow.ellipsis,
                            style: TextStyle(
                                fontSize: (widget.param.fontSize != null)
                                    ? widget.param.fontSize
                                    : con.font_medium,
                                color: (param.textColor != null)
                                    ? param.textColor
                                    : Theme.of(context)
                                        .textTheme
                                        .bodyText1
                                        .color,
                                fontWeight: widget.param.fontWeight),
                          )
                        : (param.listType == "NetworkImage")
                            ? Image.network(
                                value,
                                height: (widget.param.imageHeight == null)
                                    ? con.heightSixty
                                    : widget.param.imageHeight,
                                width: (widget.param.imageWidth == null)
                                    ? con.image_width
                                    : widget.param.imageWidth,
                              )
                            : (param.listType == con.AsseImage)
                                ? Image.asset(
                                    value,
                                    height: (widget.param.imageHeight == null)
                                        ? con.heightSixty
                                        : widget.param.imageHeight,
                                    width: (widget.param.imageWidth == null)
                                        ? con.image_width
                                        : widget.param.imageWidth,
                                  )
                                : Text(
                                    value,
                                    style: TextStyle(
                                      fontSize: (widget.param.fontSize != null)
                                          ? widget.param.fontSize
                                          : con.font_medium,
                                      color: (param.textColor != null)
                                          ? param.textColor
                                          : Theme.of(context)
                                              .textTheme
                                              .bodyText2
                                              .color,
                                      fontWeight: (param.fontWeight != null)
                                          ? param.fontWeight
                                          : Theme.of(context)
                                              .textTheme
                                              .bodyText2
                                              .fontWeight,
                                      fontFamily: (param.fontFamily != null)
                                          ? param.fontFamily
                                          : Theme.of(context)
                                              .textTheme
                                              .bodyText2
                                              .fontFamily,
                                      fontStyle: (param.fontStyle != null)
                                          ? param.fontStyle
                                          : Theme.of(context)
                                              .textTheme
                                              .bodyText2
                                              .fontStyle,
                                    ),
                                  ),
                  );
                }).toList(),
                hint: Text(
                  (widget.param.hintText != null)
                      ? widget.param.hintText
                      : con.sampleText,
                  overflow: TextOverflow.ellipsis,
                  textAlign: (widget.param.textAlign == null)
                      ? TextAlign.left
                      : widget.param.textAlign,
                  style: TextStyle(
                    fontSize: (widget.param.fontSize != null)
                        ? widget.param.fontSize
                        : con.font_medium,
                    color: (param.hintTextColor != null)
                        ? param.hintTextColor
                        : Theme.of(context).textTheme.subtitle1.color,
                    fontWeight: (param.hintFontWeight != null)
                        ? param.hintFontWeight
                        : Theme.of(context).textTheme.subtitle1.fontWeight,
                    fontFamily: (param.hintfontFamily != null)
                        ? param.hintfontFamily
                        : Theme.of(context).textTheme.subtitle1.fontFamily,
                    fontStyle: (param.hintFontStyle != null)
                        ? param.hintFontStyle
                        : Theme.of(context).textTheme.subtitle1.fontStyle,
                  ),
                ),
                // setting hint
                onChanged: (String value) {
                  setState(() {
                    dropdownValue = value;
                    widget.callback(
                        widget.param.itemsList.indexOf(value), dropdownValue);
                  });
                },

                value: dropdownValue,
              ),
            )),
      );
    }
  }
}
